@@ -18,14 +18,10 @@
 #   You should have received a copy of the GNU General Public License along
 #   with this program; if not, see <http://www.gnu.org/licenses/>.
 
-from smartcard.System import readers
-from smartcard.pcsc.PCSCPart10 import (
-    SCARD_SHARE_DIRECT,
-    SCARD_LEAVE_CARD,
-    SCARD_CTL_CODE,
-    getTlvProperties,
-)
 from smartcard import Exceptions
+from smartcard.pcsc.PCSCPart10 import SCARD_CTL_CODE, getTlvProperties
+from smartcard.scard import SCARD_LEAVE_CARD, SCARD_SHARE_DIRECT
+from smartcard.System import readers
 
 for reader in readers():
     cardConnection = reader.createConnection()
@@ -57,6 +53,6 @@ for reader in readers():
                 firmware = properties[key]
                 print(" Firmware:", firmware)
             else:
-                print(" %s not supported" % key)
+                print(f" {key} not supported")
     else:
-        print(" %s not supported" % key)
+        print(f" {key} not supported")
